==> haskell-doclayout-0.5-9.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doclayout
version:              0.5
visibility:           public
id:                   doclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r
key:                  doclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r
license:              BSD-3-Clause
copyright:            2016-24 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  285d6908efa02f963bf35a18719fdbe3
exposed:              True
exposed-modules:      Text.DocLayout
hidden-modules:
    Text.DocLayout.HasChars Text.DocLayout.ANSIFont
    Text.DocLayout.Attributed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r
depends:
    base-4.18.2.1 containers-0.6.7 emojis-0.1.4.1-VOXDtaadLD4hNN8sCPzYl
    mtl-2.3.1 safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doclayout-0.5-10-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doclayout
version:              0.5
visibility:           public
id:                   doclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2
key:                  doclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2
license:              BSD-3-Clause
copyright:            2016-24 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  23b55caa15888b58882073c5773376b5
exposed:              True
exposed-modules:      Text.DocLayout
hidden-modules:
    Text.DocLayout.HasChars Text.DocLayout.ANSIFont
    Text.DocLayout.Attributed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doclayout-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2
depends:
    base-4.18.2.1 containers-0.6.7
    emojis-0.1.4.1-L7mOnPsQOMB2xPGhke4egp mtl-2.3.1
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
